@@ -8,7 +8,7 @@
 // return>0: amounts of bytes read, the device will be open and the internal
 // seek pointer point to position+length
 // return<0: error. the device will be open but in undefined condition
-off_t read_deperately(char* filename, int *fd, unsigned char* buffer,
+off_t read_desperately(char* filename, int *fd, char* buffer,
 			off_t position, off_t length,
 			int seekable, int recovery, int syncmode);
 
