@@ -19,8 +19,9 @@ function test_current() {
 
 	testsuite_debug "Test, first run with big skipsize and resolution to produce output with holes"
 	testsuite_debug " Must not touch exclude blocks."
-	if ! LD_PRELOAD="$preload" $safecopy -R 2 -b 1150 -f 4* -r 4* -x 490 -X xblocks -o "$testsuite_tmpdir/test1.badblocks" debug "$testsuite_tmpdir/test1.dat" >"$testsuite_tmpdir/test1.out" 2>&1; then
-		testsuite_error "Run of safecopy failed. Output:"
+	LD_PRELOAD="$preload" $safecopy -R 2 -b 1150 -f 4* -r 4* -x 490 -X xblocks -o "$testsuite_tmpdir/test1.badblocks" debug "$testsuite_tmpdir/test1.dat" >"$testsuite_tmpdir/test1.out" 2>&1
+	if [ $? != 1 ]; then
+		testsuite_error "Run of safecopy returned wrong exit code. Output:"
                 testsuite_debug_file "$testsuite_tmpdir/test1.out"
 	fi
 	testsuite_assert_files_identical "test1.dat" "$testsuite_tmpdir/test1.dat"
@@ -28,8 +29,9 @@ function test_current() {
 
 	testsuite_debug "Test, first run with big skipsize and resolution to produce output with holes + marking"
 	testsuite_debug " Must not touch exclude blocks."
-	if ! LD_PRELOAD="$preload" $safecopy -M "MARKBAAD" -R 2 -b 1150 -f 4* -r 4* -x 490 -X xblocks -o "$testsuite_tmpdir/test2.badblocks" debug "$testsuite_tmpdir/test2.dat" >"$testsuite_tmpdir/test2.out" 2>&1; then
-		testsuite_error "Run of safecopy failed. Output:"
+	LD_PRELOAD="$preload" $safecopy -M "MARKBAAD" -R 2 -b 1150 -f 4* -r 4* -x 490 -X xblocks -o "$testsuite_tmpdir/test2.badblocks" debug "$testsuite_tmpdir/test2.dat" >"$testsuite_tmpdir/test2.out" 2>&1
+	if [ $? != 1 ]; then
+		testsuite_error "Run of safecopy returned wrong exit code. Output:"
                 testsuite_debug_file "$testsuite_tmpdir/test2.out"
 	fi
 	testsuite_assert_files_identical "test2.dat" "$testsuite_tmpdir/test2.dat"
@@ -39,8 +41,9 @@ function test_current() {
 	testsuite_debug " Must transpose badblocks to correct new sectorsize."
 	testsuite_debug " Must recover data at the end of bad areas but not overwrite already recovered data."
 	testsuite_debug " Must not touch exclude blocks."
-	if ! LD_PRELOAD="$preload" $safecopy -R 2 -b 1024 -f 8* -i 1150 -I "$testsuite_tmpdir/test1.badblocks" -x 490 -X xblocks -o "$testsuite_tmpdir/test3.badblocks" debug "$testsuite_tmpdir/test3.dat" >"$testsuite_tmpdir/test3.out" 2>&1; then
-		testsuite_error "Run of safecopy failed. Output:"
+	LD_PRELOAD="$preload" $safecopy -R 2 -b 1024 -f 8* -i 1150 -I "$testsuite_tmpdir/test1.badblocks" -x 490 -X xblocks -o "$testsuite_tmpdir/test3.badblocks" debug "$testsuite_tmpdir/test3.dat" >"$testsuite_tmpdir/test3.out" 2>&1
+	if [ $? != 1 ]; then
+		testsuite_error "Run of safecopy returned wrong exit code. Output:"
                 testsuite_debug_file "$testsuite_tmpdir/test3.out"
 	fi
 	testsuite_assert_files_identical "test3.dat" "$testsuite_tmpdir/test3.dat"
@@ -49,8 +52,9 @@ function test_current() {
 	testsuite_debug "Test, incremental, small skipsize and atomic resolution."
 	testsuite_debug " Must recover all recoverable data"
 	testsuite_debug " Must not touch exclude blocks."
-	if ! LD_PRELOAD="$preload" $safecopy -R 2 -b 1024 -f 1* -r 1 -i 1150 -I "$testsuite_tmpdir/test1.badblocks" -x 490 -X xblocks -o "$testsuite_tmpdir/test4.badblocks" debug "$testsuite_tmpdir/test4.dat" >"$testsuite_tmpdir/test4.out" 2>&1; then
-		testsuite_error "Run of safecopy failed. Output:"
+	LD_PRELOAD="$preload" $safecopy -R 2 -b 1024 -f 1* -r 1 -i 1150 -I "$testsuite_tmpdir/test1.badblocks" -x 490 -X xblocks -o "$testsuite_tmpdir/test4.badblocks" debug "$testsuite_tmpdir/test4.dat" >"$testsuite_tmpdir/test4.out" 2>&1
+	if [ $? != 1 ]; then
+		testsuite_error "Run of safecopy returned wrong exit code. Output:"
                 testsuite_debug_file "$testsuite_tmpdir/test4.out"
 	fi
 	testsuite_assert_files_identical "test4.dat" "$testsuite_tmpdir/test4.dat"
@@ -61,8 +65,9 @@ function test_current() {
 	testsuite_debug " this one may overwrite successfully rescued data as long"
 	testsuite_debug " as it affects only blocks marked as bad in the include file"
 	testsuite_debug " Must not touch exclude blocks."
-	if ! LD_PRELOAD="$preload" $safecopy -M "MARKBAAD" -R 2 -b 1024 -f 8* -i 1150 -I "$testsuite_tmpdir/test1.badblocks" -x 490 -X xblocks -o "$testsuite_tmpdir/test5.badblocks" debug "$testsuite_tmpdir/test5.dat" >"$testsuite_tmpdir/test5.out" 2>&1; then
-		testsuite_error "Run of safecopy failed. Output:"
+	LD_PRELOAD="$preload" $safecopy -M "MARKBAAD" -R 2 -b 1024 -f 8* -i 1150 -I "$testsuite_tmpdir/test1.badblocks" -x 490 -X xblocks -o "$testsuite_tmpdir/test5.badblocks" debug "$testsuite_tmpdir/test5.dat" >"$testsuite_tmpdir/test5.out" 2>&1
+	if [ $? != 1 ]; then
+		testsuite_error "Run of safecopy returned wrong exit code. Output:"
                 testsuite_debug_file "$testsuite_tmpdir/test5.out"
 	fi
 	testsuite_assert_files_identical "test5.dat" "$testsuite_tmpdir/test5.dat"
@@ -71,8 +76,9 @@ function test_current() {
 	testsuite_debug "Test, incremental, small skipsize and atomic resolution, with marking."
 	testsuite_debug " Must only differ from test4.dat by shifts of marker strings, no real data differences"
 	testsuite_debug " Must not touch exclude blocks."
-	if ! LD_PRELOAD="$preload" $safecopy -M "MARKBAAD" -R 2 -b 1024 -f 1* -r 1 -i 1150 -I "$testsuite_tmpdir/test1.badblocks" -x 490 -X xblocks -o "$testsuite_tmpdir/test6.badblocks" debug "$testsuite_tmpdir/test6.dat" >"$testsuite_tmpdir/test6.out" 2>&1; then
-		testsuite_error "Run of safecopy failed. Output:"
+	LD_PRELOAD="$preload" $safecopy -M "MARKBAAD" -R 2 -b 1024 -f 1* -r 1 -i 1150 -I "$testsuite_tmpdir/test1.badblocks" -x 490 -X xblocks -o "$testsuite_tmpdir/test6.badblocks" debug "$testsuite_tmpdir/test6.dat" >"$testsuite_tmpdir/test6.out" 2>&1
+	if [ $? != 1 ]; then
+		testsuite_error "Run of safecopy returned wrong exit code. Output:"
                 testsuite_debug_file "$testsuite_tmpdir/test6.out"
 	fi
 	testsuite_assert_files_identical "test6.dat" "$testsuite_tmpdir/test6.dat"
